pm4py.algo.conformance.antialignments package
=============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.antialignments.variants

Submodules
----------

pm4py.algo.conformance.antialignments.algorithm module
------------------------------------------------------

.. automodule:: pm4py.algo.conformance.antialignments.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.antialignments
   :members:
   :undoc-members:
   :show-inheritance:
